pub struct ChannelSwitchInfo {
pub new_primary_channel: ChannelNumber,
pub bandwidth: ChannelBandwidth,
pub vht_secondary_80_channel: ChannelNumber,
}Fields
new_primary_channel: ChannelNumberbandwidth: ChannelBandwidthvht_secondary_80_channel: ChannelNumberTrait Implementations
Sourceimpl Clone for ChannelSwitchInfo
impl Clone for ChannelSwitchInfo
Sourcefn clone(&self) -> ChannelSwitchInfo
fn clone(&self) -> ChannelSwitchInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChannelSwitchInfo
impl Debug for ChannelSwitchInfo
Sourceimpl<___E> Encode<ChannelSwitchInfo, ___E> for ChannelSwitchInfowhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<ChannelSwitchInfo, ___E> for ChannelSwitchInfowhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ChannelSwitchInfo>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ChannelSwitchInfo>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<ChannelSwitchInfo, ___E> for &'a ChannelSwitchInfowhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<ChannelSwitchInfo, ___E> for &'a ChannelSwitchInfowhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ChannelSwitchInfo>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ChannelSwitchInfo>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, ChannelSwitchInfo>, ___E> for ChannelSwitchInfo
impl<___E> EncodeOption<Box<'static, ChannelSwitchInfo>, ___E> for ChannelSwitchInfo
Sourcefn encode_option(
this: Option<ChannelSwitchInfo>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ChannelSwitchInfo>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<ChannelSwitchInfo>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ChannelSwitchInfo>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, ChannelSwitchInfo>, ___E> for &'a ChannelSwitchInfo
impl<'a, ___E> EncodeOption<Box<'static, ChannelSwitchInfo>, ___E> for &'a ChannelSwitchInfo
Sourcefn encode_option(
this: Option<&'a ChannelSwitchInfo>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ChannelSwitchInfo>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a ChannelSwitchInfo>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ChannelSwitchInfo>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<ChannelSwitchInfo> for ChannelSwitchInfo
impl FromWire<ChannelSwitchInfo> for ChannelSwitchInfo
Sourcefn from_wire(wire: ChannelSwitchInfo) -> ChannelSwitchInfo
fn from_wire(wire: ChannelSwitchInfo) -> ChannelSwitchInfo
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<ChannelSwitchInfo> for ChannelSwitchInfo
impl FromWireRef<ChannelSwitchInfo> for ChannelSwitchInfo
Sourcefn from_wire_ref(wire: &ChannelSwitchInfo) -> ChannelSwitchInfo
fn from_wire_ref(wire: &ChannelSwitchInfo) -> ChannelSwitchInfo
Converts the given reference to this type.
Sourceimpl PartialEq for ChannelSwitchInfo
impl PartialEq for ChannelSwitchInfo
Sourcefn eq(&self, other: &ChannelSwitchInfo) -> bool
fn eq(&self, other: &ChannelSwitchInfo) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ChannelSwitchInfo