#[repr(C)]pub struct SignalReportIndication {
pub rssi_dbm: i8,
pub snr_db: i8,
}Fields
rssi_dbm: i8snr_db: i8Trait Implementations
Sourceimpl Clone for SignalReportIndication
impl Clone for SignalReportIndication
Sourcefn clone(&self) -> SignalReportIndication
fn clone(&self) -> SignalReportIndication
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for SignalReportIndication
Sourceimpl Debug for SignalReportIndication
impl Debug for SignalReportIndication
Sourceimpl<___E> Encode<SignalReportIndication, ___E> for SignalReportIndicationwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<SignalReportIndication, ___E> for SignalReportIndicationwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<SignalReportIndication, SignalReportIndication>
const COPY_OPTIMIZATION: CopyOptimization<SignalReportIndication, SignalReportIndication>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SignalReportIndication>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SignalReportIndication>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<SignalReportIndication, ___E> for &'a SignalReportIndicationwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<SignalReportIndication, ___E> for &'a SignalReportIndicationwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SignalReportIndication>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SignalReportIndication>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, SignalReportIndication>, ___E> for SignalReportIndication
impl<___E> EncodeOption<Box<'static, SignalReportIndication>, ___E> for SignalReportIndication
Sourcefn encode_option(
this: Option<SignalReportIndication>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SignalReportIndication>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<SignalReportIndication>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SignalReportIndication>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, SignalReportIndication>, ___E> for &'a SignalReportIndication
impl<'a, ___E> EncodeOption<Box<'static, SignalReportIndication>, ___E> for &'a SignalReportIndication
Sourcefn encode_option(
this: Option<&'a SignalReportIndication>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SignalReportIndication>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a SignalReportIndication>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SignalReportIndication>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for SignalReportIndication
Sourceimpl FromWire<SignalReportIndication> for SignalReportIndication
impl FromWire<SignalReportIndication> for SignalReportIndication
Sourceconst COPY_OPTIMIZATION: CopyOptimization<SignalReportIndication, SignalReportIndication>
const COPY_OPTIMIZATION: CopyOptimization<SignalReportIndication, SignalReportIndication>
Sourcefn from_wire(wire: SignalReportIndication) -> SignalReportIndication
fn from_wire(wire: SignalReportIndication) -> SignalReportIndication
Converts the given owned value to this type.
Sourceimpl FromWireRef<SignalReportIndication> for SignalReportIndication
impl FromWireRef<SignalReportIndication> for SignalReportIndication
Sourcefn from_wire_ref(wire: &SignalReportIndication) -> SignalReportIndication
fn from_wire_ref(wire: &SignalReportIndication) -> SignalReportIndication
Converts the given reference to this type.
Sourceimpl Hash for SignalReportIndication
impl Hash for SignalReportIndication
Sourceimpl Ord for SignalReportIndication
impl Ord for SignalReportIndication
Sourcefn cmp(&self, other: &SignalReportIndication) -> Ordering
fn cmp(&self, other: &SignalReportIndication) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for SignalReportIndication
impl PartialEq for SignalReportIndication
Sourcefn eq(&self, other: &SignalReportIndication) -> bool
fn eq(&self, other: &SignalReportIndication) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for SignalReportIndication
impl PartialOrd for SignalReportIndication
impl StructuralPartialEq for SignalReportIndication