pub struct WepCredentials {
pub key: Vec<u8>,
}Expand description
WEP credentials.
Fields
key: Vec<u8>Trait Implementations
Sourceimpl Clone for WepCredentials
impl Clone for WepCredentials
Sourcefn clone(&self) -> WepCredentials
fn clone(&self) -> WepCredentials
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WepCredentials
impl Debug for WepCredentials
Sourceimpl<___E> Encode<WepCredentials<'static>, ___E> for WepCredentialswhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<WepCredentials<'static>, ___E> for WepCredentialswhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<WepCredentials<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<WepCredentials<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<WepCredentials<'static>, ___E> for &'a WepCredentialswhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<WepCredentials<'static>, ___E> for &'a WepCredentialswhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<WepCredentials<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<WepCredentials<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, WepCredentials<'static>>, ___E> for WepCredentials
impl<___E> EncodeOption<Box<'static, WepCredentials<'static>>, ___E> for WepCredentials
Sourcefn encode_option(
this: Option<WepCredentials>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, WepCredentials<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<WepCredentials>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, WepCredentials<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, WepCredentials<'static>>, ___E> for &'a WepCredentials
impl<'a, ___E> EncodeOption<Box<'static, WepCredentials<'static>>, ___E> for &'a WepCredentials
Sourcefn encode_option(
this: Option<&'a WepCredentials>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, WepCredentials<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a WepCredentials>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, WepCredentials<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for WepCredentials
Sourceimpl<'de> FromWire<WepCredentials<'de>> for WepCredentials
impl<'de> FromWire<WepCredentials<'de>> for WepCredentials
Sourcefn from_wire(wire: WepCredentials<'de>) -> WepCredentials
fn from_wire(wire: WepCredentials<'de>) -> WepCredentials
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<WepCredentials<'de>> for WepCredentials
impl<'de> FromWireRef<WepCredentials<'de>> for WepCredentials
Sourcefn from_wire_ref(wire: &WepCredentials<'de>) -> WepCredentials
fn from_wire_ref(wire: &WepCredentials<'de>) -> WepCredentials
Converts the given reference to this type.
Sourceimpl Hash for WepCredentials
impl Hash for WepCredentials
Sourceimpl Ord for WepCredentials
impl Ord for WepCredentials
Sourcefn cmp(&self, other: &WepCredentials) -> Ordering
fn cmp(&self, other: &WepCredentials) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for WepCredentials
impl PartialEq for WepCredentials
Sourcefn eq(&self, other: &WepCredentials) -> bool
fn eq(&self, other: &WepCredentials) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for WepCredentials
impl PartialOrd for WepCredentials
impl StructuralPartialEq for WepCredentials