pub struct Authentication {
pub protocol: Protocol,
pub credentials: Option<Box<Credentials>>,
}Expand description
Pairs credentials with a particular security protocol. This type requires
validation, as Protocol and Credentials may disagree. FIDL APIs that use
this type generally restrict authentication to protocol.
Fields
protocol: Protocolcredentials: Option<Box<Credentials>>Trait Implementations
Sourceimpl Clone for Authentication
impl Clone for Authentication
Sourcefn clone(&self) -> Authentication
fn clone(&self) -> Authentication
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Authentication
impl Debug for Authentication
Sourceimpl<___E> Encode<Authentication<'static>, ___E> for Authenticationwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<Authentication<'static>, ___E> for Authenticationwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Authentication<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Authentication<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<Authentication<'static>, ___E> for &'a Authenticationwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<Authentication<'static>, ___E> for &'a Authenticationwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Authentication<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Authentication<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, Authentication<'static>>, ___E> for Authentication
impl<___E> EncodeOption<Box<'static, Authentication<'static>>, ___E> for Authentication
Sourcefn encode_option(
this: Option<Authentication>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Authentication<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Authentication>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Authentication<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Authentication<'static>>, ___E> for &'a Authentication
impl<'a, ___E> EncodeOption<Box<'static, Authentication<'static>>, ___E> for &'a Authentication
Sourcefn encode_option(
this: Option<&'a Authentication>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Authentication<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a Authentication>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Authentication<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for Authentication
Sourceimpl<'de> FromWire<Authentication<'de>> for Authentication
impl<'de> FromWire<Authentication<'de>> for Authentication
Sourcefn from_wire(wire: Authentication<'de>) -> Authentication
fn from_wire(wire: Authentication<'de>) -> Authentication
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<Authentication<'de>> for Authentication
impl<'de> FromWireRef<Authentication<'de>> for Authentication
Sourcefn from_wire_ref(wire: &Authentication<'de>) -> Authentication
fn from_wire_ref(wire: &Authentication<'de>) -> Authentication
Converts the given reference to this type.
Sourceimpl Hash for Authentication
impl Hash for Authentication
Sourceimpl Ord for Authentication
impl Ord for Authentication
Sourcefn cmp(&self, other: &Authentication) -> Ordering
fn cmp(&self, other: &Authentication) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Authentication
impl PartialEq for Authentication
Sourcefn eq(&self, other: &Authentication) -> bool
fn eq(&self, other: &Authentication) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for Authentication
impl PartialOrd for Authentication
impl StructuralPartialEq for Authentication