pub struct WmmAcParams {
pub ecw_min: u8,
pub ecw_max: u8,
pub aifsn: u8,
pub txop_limit: u16,
pub acm: bool,
}Expand description
WFA WMM v1.2, 2.2.2
Fields
ecw_min: u8ecw_max: u8aifsn: u8txop_limit: u16acm: boolTrait Implementations
Sourceimpl Clone for WmmAcParams
impl Clone for WmmAcParams
Sourcefn clone(&self) -> WmmAcParams
fn clone(&self) -> WmmAcParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for WmmAcParams
Sourceimpl Debug for WmmAcParams
impl Debug for WmmAcParams
Sourceimpl<___E> Encode<WmmAcParams, ___E> for WmmAcParamswhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<WmmAcParams, ___E> for WmmAcParamswhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<WmmAcParams>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<WmmAcParams>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<WmmAcParams, ___E> for &'a WmmAcParamswhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<WmmAcParams, ___E> for &'a WmmAcParamswhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<WmmAcParams>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<WmmAcParams>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, WmmAcParams>, ___E> for WmmAcParams
impl<___E> EncodeOption<Box<'static, WmmAcParams>, ___E> for WmmAcParams
Sourcefn encode_option(
this: Option<WmmAcParams>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, WmmAcParams>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<WmmAcParams>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, WmmAcParams>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, WmmAcParams>, ___E> for &'a WmmAcParams
impl<'a, ___E> EncodeOption<Box<'static, WmmAcParams>, ___E> for &'a WmmAcParams
Sourcefn encode_option(
this: Option<&'a WmmAcParams>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, WmmAcParams>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a WmmAcParams>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, WmmAcParams>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for WmmAcParams
Sourceimpl FromWire<WmmAcParams> for WmmAcParams
impl FromWire<WmmAcParams> for WmmAcParams
Sourcefn from_wire(wire: WmmAcParams) -> WmmAcParams
fn from_wire(wire: WmmAcParams) -> WmmAcParams
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<WmmAcParams> for WmmAcParams
impl FromWireRef<WmmAcParams> for WmmAcParams
Sourcefn from_wire_ref(wire: &WmmAcParams) -> WmmAcParams
fn from_wire_ref(wire: &WmmAcParams) -> WmmAcParams
Converts the given reference to this type.
Sourceimpl Hash for WmmAcParams
impl Hash for WmmAcParams
Sourceimpl Ord for WmmAcParams
impl Ord for WmmAcParams
Sourcefn cmp(&self, other: &WmmAcParams) -> Ordering
fn cmp(&self, other: &WmmAcParams) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for WmmAcParams
impl PartialEq for WmmAcParams
Sourcefn eq(&self, other: &WmmAcParams) -> bool
fn eq(&self, other: &WmmAcParams) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for WmmAcParams
impl PartialOrd for WmmAcParams
impl StructuralPartialEq for WmmAcParams