#[repr(C)]pub struct ChannelSwitchInfo {
pub new_primary_channel: ChannelNumber,
pub bandwidth: ChannelBandwidth,
pub vht_secondary_80_channel: ChannelNumber,
}Expand description
The wire type corresponding to ChannelSwitchInfo.
Fields
new_primary_channel: ChannelNumberbandwidth: ChannelBandwidthvht_secondary_80_channel: ChannelNumberTrait Implementations
Sourceimpl Clone for ChannelSwitchInfo
impl Clone for ChannelSwitchInfo
Sourcefn clone(&self) -> ChannelSwitchInfo
fn clone(&self) -> ChannelSwitchInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for ChannelSwitchInfo
impl Constrained for ChannelSwitchInfo
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, ChannelSwitchInfo>,
_: <ChannelSwitchInfo as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, ChannelSwitchInfo>, _: <ChannelSwitchInfo as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for ChannelSwitchInfo
impl Debug for ChannelSwitchInfo
Sourceimpl<___D> Decode<___D> for ChannelSwitchInfowhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for ChannelSwitchInfowhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<___E> Encode<ChannelSwitchInfo, ___E> for ChannelSwitchInfowhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<ChannelSwitchInfo, ___E> for ChannelSwitchInfowhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ChannelSwitchInfo>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ChannelSwitchInfo>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<ChannelSwitchInfo, ___E> for &'a ChannelSwitchInfowhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<ChannelSwitchInfo, ___E> for &'a ChannelSwitchInfowhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ChannelSwitchInfo>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ChannelSwitchInfo>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1, T2> Encode<ChannelSwitchInfo, ___E> for ChannelSwitchInfo<T0, T1, T2>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<ChannelNumber, ___E>,
T1: Encode<ChannelBandwidth, ___E>,
T2: Encode<ChannelNumber, ___E>,
impl<___E, T0, T1, T2> Encode<ChannelSwitchInfo, ___E> for ChannelSwitchInfo<T0, T1, T2>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<ChannelNumber, ___E>,
T1: Encode<ChannelBandwidth, ___E>,
T2: Encode<ChannelNumber, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ChannelSwitchInfo>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ChannelSwitchInfo>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<ChannelSwitchInfo> for ChannelSwitchInfo
impl FromWire<ChannelSwitchInfo> for ChannelSwitchInfo
Sourcefn from_wire(wire: ChannelSwitchInfo) -> ChannelSwitchInfo
fn from_wire(wire: ChannelSwitchInfo) -> ChannelSwitchInfo
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<ChannelSwitchInfo> for ChannelSwitchInfo
impl FromWireRef<ChannelSwitchInfo> for ChannelSwitchInfo
Sourcefn from_wire_ref(wire: &ChannelSwitchInfo) -> ChannelSwitchInfo
fn from_wire_ref(wire: &ChannelSwitchInfo) -> ChannelSwitchInfo
Converts the given reference to this type.
Sourceimpl IntoNatural for ChannelSwitchInfo
impl IntoNatural for ChannelSwitchInfo
Sourcetype Natural = ChannelSwitchInfo
type Natural = ChannelSwitchInfo
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ChannelSwitchInfo
impl Wire for ChannelSwitchInfo
Sourcetype Narrowed<'de> = ChannelSwitchInfo
type Narrowed<'de> = ChannelSwitchInfo
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<ChannelSwitchInfo>)
fn zero_padding(out_: &mut MaybeUninit<ChannelSwitchInfo>)
Writes zeroes to the padding for this type, if any.