#[repr(C)]pub struct SignalReportIndication {
pub rssi_dbm: i8,
pub snr_db: i8,
}Expand description
The wire type corresponding to SignalReportIndication.
Fields
rssi_dbm: i8snr_db: i8Trait Implementations
Sourceimpl Clone for SignalReportIndication
impl Clone for SignalReportIndication
Sourcefn clone(&self) -> SignalReportIndication
fn clone(&self) -> SignalReportIndication
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for SignalReportIndication
impl Constrained for SignalReportIndication
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, SignalReportIndication>,
_: <SignalReportIndication as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, SignalReportIndication>, _: <SignalReportIndication as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for SignalReportIndication
impl Debug for SignalReportIndication
Sourceimpl<___D> Decode<___D> for SignalReportIndicationwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for SignalReportIndicationwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<___E> Encode<SignalReportIndication, ___E> for SignalReportIndicationwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<SignalReportIndication, ___E> for SignalReportIndicationwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<SignalReportIndication, SignalReportIndication>
const COPY_OPTIMIZATION: CopyOptimization<SignalReportIndication, SignalReportIndication>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SignalReportIndication>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SignalReportIndication>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<SignalReportIndication, ___E> for &'a SignalReportIndicationwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<SignalReportIndication, ___E> for &'a SignalReportIndicationwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SignalReportIndication>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SignalReportIndication>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1> Encode<SignalReportIndication, ___E> for SignalReportIndication<T0, T1>
impl<___E, T0, T1> Encode<SignalReportIndication, ___E> for SignalReportIndication<T0, T1>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SignalReportIndication>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SignalReportIndication>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<SignalReportIndication> for SignalReportIndication
impl FromWire<SignalReportIndication> for SignalReportIndication
Sourceconst COPY_OPTIMIZATION: CopyOptimization<SignalReportIndication, SignalReportIndication>
const COPY_OPTIMIZATION: CopyOptimization<SignalReportIndication, SignalReportIndication>
Sourcefn from_wire(wire: SignalReportIndication) -> SignalReportIndication
fn from_wire(wire: SignalReportIndication) -> SignalReportIndication
Converts the given owned value to this type.
Sourceimpl FromWireRef<SignalReportIndication> for SignalReportIndication
impl FromWireRef<SignalReportIndication> for SignalReportIndication
Sourcefn from_wire_ref(wire: &SignalReportIndication) -> SignalReportIndication
fn from_wire_ref(wire: &SignalReportIndication) -> SignalReportIndication
Converts the given reference to this type.
Sourceimpl IntoNatural for SignalReportIndication
impl IntoNatural for SignalReportIndication
Sourcetype Natural = SignalReportIndication
type Natural = SignalReportIndication
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for SignalReportIndication
impl Wire for SignalReportIndication
Sourcetype Narrowed<'de> = SignalReportIndication
type Narrowed<'de> = SignalReportIndication
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<SignalReportIndication>)
fn zero_padding(out_: &mut MaybeUninit<SignalReportIndication>)
Writes zeroes to the padding for this type, if any.